/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.admin.EditUserViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var CoreAdminMessages	    = dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");
var UserClient				= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var Util					= com.ibm.rational.report.web.core.app.internal.Util;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

var USER_TITLE_IMG_SRC	= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/user.gif");

/**
 * Displays the Edit User view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.admin.EditUserViewer",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/admin/templates/EditUserViewer.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
		this._userName = args.userName;
		this._editUserProfile = args.editUserProfile;
	},
	
	postCreate: function() {
		Util.removeChildren(this.pageTitle);
		var pageTitleIcon = document.createElement("img");
		pageTitleIcon.src = USER_TITLE_IMG_SRC;
		this.pageTitle.appendChild(pageTitleIcon);
		this.pageTitle.appendChild(document.createTextNode(this._userName));
		
		Util.removeChildren(this.saveButton);
		this.saveButton.appendChild(document.createTextNode(CommonMessages.SAVE_BUTTON_LABEL));
		
		Util.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
		
		Util.removeChildren(this.editUserIdLabel);
		this.editUserIdLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_USER_ID_LABEL));
/*
		Util.removeChildren(this.editUserPasswordLabel);
		this.editUserPasswordLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_PASSWORD_LABEL));
	*/	
		Util.removeChildren(this.editUserFirstNameLabel);
		this.editUserFirstNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_FIRST_NAME_LABEL));
		
		Util.removeChildren(this.editUserLastNameLabel);
		this.editUserLastNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_LAST_NAME_LABEL));
		
		Util.removeChildren(this.editUserScreenNameLabel);
		this.editUserScreenNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_SCREEN_NAME_LABEL));
		
		Util.removeChildren(this.editUserEmailLabel);
		this.editUserEmailLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_EMAIL_LABEL));
/*		
		Util.removeChildren(this.editPasswordChangeResetLabel);
		this.editPasswordChangeResetLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_PASSWORD_CHANGE_RESET_LABEL));
		
		Util.removeChildren(this.editPassword);
		this.editPassword.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_PASSWORD_CHANGE_LABEL));
		
		Util.removeChildren(this.resetPassword);
		this.resetPassword.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_PASSWORD_RESET_LABEL));
*/		
		this._msgFormatter = new MessageFormatter(this.messageArea);

		this._adminUser = "";
		this._loginUser = "";
		
		var self = this;
/*		this.editPassword.href = "javascript:{}";
		this.editPassword.onclick = function () {
			var args = new Object();
			args.userName = self._userName;
			args.editUserProfile = self._editUserProfile;
			self._controller.editPassword(args);
		}
		
		this.resetPassword.href = "javascript:{}";
		this.resetPassword.onclick = function () {
			var args = new Object();
			args.userName = self._userName;
			args.editUserProfile = self._editUserProfile;			
			self._controller.resetPassword(args);
		}
*/
		var responseHandler = new ServiceResponseHandler(
			this,
			"_displayUserAttribute",
			"_getUserAttributesError");
		UserClient.getUserAttributes(responseHandler, {name: this._userName});
		
		var self = this;
		
		var responseHandler = new ServiceResponseHandler(
			this,
			"_gotAdminUser",
			"_gotAdminUserError");
		UserClient.getAdminUser(responseHandler);
		
		var responseHandler = new ServiceResponseHandler(
			this,
			"_gotUser",
			"_gotUserError");
		UserClient.getAuthenticatedUser(responseHandler);
		
		dojo.connect(this.saveButton, "onclick",
			function(e) {
				e.preventDefault();
				self._updateUser();
			}
		);
		
		dojo.connect(this.closeButton, "onclick",
			function(e) {
				e.preventDefault();
				self._exitPage();
			}
		);
		
		dojo.connect(this.editUserForm, "onkeyup",
			function(e) {
				e.preventDefault();
				self.validateUserInput();
			}
		);
	},
	
	_gotAdminUser: function(result) {
	    this._adminUser = result.name;
	},
	
	_gotAdminUserError: function(result) {
	    this._adminUser = "";
	},
	
	_gotUser: function(result) {
	    this._loginUser = result.name;
	},

	_gotUserError: function(result) {
	    this._loginUser = "";
	},
	
	_displayUserAttribute: function(userAttr) {
		this.editUserId.value = userAttr.name;
		this.editUserFirstName.value = userAttr.firstName;
		this.editUserLastName.value = userAttr.lastName;
	   	this.editUserScreenName.value = userAttr.screenName;	    	    	    
	    this.editUserEmail.value = userAttr.email;
	},
	
	_getUserAttributesError: function(error) {
		var msg = dojo.string.substitute(
				ServiceabilityMessages.FAILED_TO_RETRIEVE_USER_PROFILE, [dojo.trim(this._userName)]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
	
	_deleteUser: function() {
		var responseHandler = new ServiceResponseHandler(
			this,
			"_postDeleteUserSuccess",
			"_postDeleteUserError");
		UserClient.postDeleteUser(responseHandler, {name: this._userName});
	},
	
	_postDeleteUserSuccess: function() {
		Util.removeChildren(this.messageArea);
		this._exitPage();
	},
	
	_postDeleteUserError: function(error) {
		var msg = dojo.string.substitute(ServiceabilityMessages.FAILED_TO_DELETE_USER, [dojo.trim(this._userName)]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
	
	_updateUser: function() {
		Util.removeChildren(this.messageArea);
		this.saveButton.disabled = true;
		var responseHandler = new ServiceResponseHandler(
			this,
			"_exitPage",
			"_postUpdateUserAttributesError");
		var args = {
			name: dojo.trim(this.editUserId.value),
			firstName: dojo.trim(this.editUserFirstName.value),
			lastName: dojo.trim(this.editUserLastName.value),
			screenName: dojo.trim(this.editUserScreenName.value),
			email: dojo.trim(this.editUserEmail.value)
		};
		UserClient.postUpdateUserAttributes(responseHandler, args);
	},
	
	_postUpdateUserAttributesError: function(error) {
		var msg = dojo.string.substitute(ServiceabilityMessages.FAILED_TO_UPDATE_USER, [dojo.trim(this._userName)]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
	
	validateUserInput: function(e) {
		if (dojo.trim(this.editUserId.value).length === 0 ||		
			dojo.trim(this.editUserFirstName.value).length === 0 ||
			dojo.trim(this.editUserLastName.value).length === 0 ||
			dojo.trim(this.editUserScreenName.value).length === 0 ||
			dojo.trim(this.editUserEmail.value).length === 0) {
			this.saveButton.disabled = true;
		}
		else {
			this.saveButton.disabled = false;
		}
	},
	
	_exitPage: function() {
	    if (typeof this._editUserProfile != "undefined") {
			this.controller.clearMainContent(); 
		}
		else {
			this.controller.manageUsers(); 			
		}		
	}
	
});

})();